@@ -1,34 +1,35 @@
-/*
- *
- * Copyright 2019 gRPC authors.
- *
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
- *
- *     http://www.apache.org/licenses/LICENSE-2.0
- *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
- *
- */
+//
+//
+// Copyright 2019 gRPC authors.
+//
+// Licensed under the Apache License, Version 2.0 (the "License");
+// you may not use this file except in compliance with the License.
+// You may obtain a copy of the License at
+//
+//     http://www.apache.org/licenses/LICENSE-2.0
+//
+// Unless required by applicable law or agreed to in writing, software
+// distributed under the License is distributed on an "AS IS" BASIS,
+// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+// See the License for the specific language governing permissions and
+// limitations under the License.
+//
+//
 
 #include "src/core/lib/iomgr/timer.h"
 
+#include <grpc/grpc.h>
 #include <gtest/gtest.h>
 
-#include <grpc/grpc.h>
-#include <grpc/support/log.h>
-
-#include "src/core/lib/gprpp/time.h"
+#include "absl/log/check.h"
+#include "absl/log/log.h"
 #include "src/core/lib/iomgr/closure.h"
 #include "src/core/lib/iomgr/error.h"
 #include "src/core/lib/iomgr/exec_ctx.h"
 #include "src/core/lib/iomgr/timer_manager.h"
-#include "test/core/util/test_config.h"
+#include "src/core/util/crash.h"
+#include "src/core/util/time.h"
+#include "test/core/test_util/test_config.h"
 
 #ifdef GRPC_POSIX_SOCKET_EV
 #include "src/core/lib/iomgr/ev_posix.h"
@@ -76,7 +77,7 @@ TEST_F(TimerTest, NoTimers) {
   // We expect to get 1 wakeup per second. Sometimes we also get a wakeup
   // during initialization, so in 1.5 seconds we expect to get 1 or 2 wakeups.
   int64_t wakeups = grpc_timer_manager_get_wakeups_testonly();
-  GPR_ASSERT(wakeups == 1 || wakeups == 2);
+  CHECK(wakeups == 1 || wakeups == 2);
 }
 #endif
 
@@ -95,14 +96,14 @@ TEST_F(TimerTest, OneTimerExpires) {
           },
           &timer_fired, grpc_schedule_on_exec_ctx));
   gpr_sleep_until(grpc_timeout_milliseconds_to_deadline(1500));
-  GPR_ASSERT(1 == timer_fired);
+  CHECK_EQ(timer_fired, 1);
 
   // We expect to get 1 wakeup/second + 1 wakeup for the expired timer + maybe 1
   // wakeup during initialization. i.e. in 1.5 seconds we expect 2 or 3 wakeups.
   // Actual number of wakeups is more due to bug
   // https://github.com/grpc/grpc/issues/19947
   int64_t wakeups = grpc_timer_manager_get_wakeups_testonly();
-  gpr_log(GPR_DEBUG, "wakeups: %" PRId64 "", wakeups);
+  VLOG(2) << "wakeups: " << wakeups;
 }
 
 TEST_F(TimerTest, MultipleTimersExpire) {
@@ -125,14 +126,14 @@ TEST_F(TimerTest, MultipleTimersExpire) {
   }
 
   gpr_sleep_until(grpc_timeout_milliseconds_to_deadline(1500));
-  GPR_ASSERT(kNumTimers == timer_fired);
+  CHECK(kNumTimers == timer_fired);
 
   // We expect to get 1 wakeup/second + 1 wakeup for per timer fired + maybe 1
   // wakeup during initialization. i.e. in 1.5 seconds we expect 11 or 12
   // wakeups. Actual number of wakeups is more due to bug
   // https://github.com/grpc/grpc/issues/19947
   int64_t wakeups = grpc_timer_manager_get_wakeups_testonly();
-  gpr_log(GPR_DEBUG, "wakeups: %" PRId64 "", wakeups);
+  VLOG(2) << "wakeups: " << wakeups;
 }
 
 TEST_F(TimerTest, CancelSomeTimers) {
@@ -167,14 +168,14 @@ TEST_F(TimerTest, CancelSomeTimers) {
   }
 
   gpr_sleep_until(grpc_timeout_milliseconds_to_deadline(1500));
-  GPR_ASSERT(kNumTimers / 2 == timer_fired);
+  CHECK(kNumTimers / 2 == timer_fired);
 
   // We expect to get 1 wakeup/second + 1 wakeup per timer fired + maybe 1
   // wakeup during initialization. i.e. in 1.5 seconds we expect 6 or 7 wakeups.
   // Actual number of wakeups is more due to bug
   // https://github.com/grpc/grpc/issues/19947
   int64_t wakeups = grpc_timer_manager_get_wakeups_testonly();
-  gpr_log(GPR_DEBUG, "wakeups: %" PRId64 "", wakeups);
+  VLOG(2) << "wakeups: " << wakeups;
 }
 
 // Enable the following test after
