@@ -16,13 +16,12 @@
 //
 //
 
+#include <grpcpp/support/error_details.h>
 #include <gtest/gtest.h>
 
-#include <grpcpp/support/error_details.h>
-
-#include "src/proto/grpc/status/status.pb.h"
+#include "google/rpc/status.pb.h"
 #include "src/proto/grpc/testing/echo_messages.pb.h"
-#include "test/core/util/test_config.h"
+#include "test/core/test_util/test_config.h"
 
 namespace grpc {
 namespace {
@@ -99,7 +98,7 @@ TEST(SetTest, OutOfScopeErrorCode) {
 }
 
 TEST(SetTest, ValidScopeErrorCode) {
-  for (int c = StatusCode::OK; c <= StatusCode::UNAUTHENTICATED; c++) {
+  for (int c = StatusCode::CANCELLED; c <= StatusCode::UNAUTHENTICATED; c++) {
     google::rpc::Status expected;
     expected.set_code(c);
     expected.set_message("I am an error message");
